# Text Converter

A Python library to convert text into different formats.

## Installation

```bash
pip install textconverterimp

```

## Usage
```bash
import textconverterim
a = 'Who kNow THat'
print(textconverterimp.to_title_case(a)) 
#or
import textconverterim as tc

a = 'Who kNow THat'
print(tc.to_title_case(a))
```